"""
My First to try build a package for pypi
"""


class NZP(object):

    def __init__(self):
        self._info = "This niuzepeng object!"

    def __str__(self):
        return self._info

    @staticmethod
    def show():
        return "This is first create my package!"



from setuptools import setup
from setuptools import find_packages

setup(
      name='niuzepeng',
      version='1.0.2',
      description='This is my first create!',
      author='Niuzepeng',
      author_email='18217127859@163.com',
      url="https://github.com/zepen",
      license='MIT',
      packages=find_packages(),
      zip_safe=False
)
